==> miscnn-0.30.tar.gz: miscnn-0.30/miscnn/processing/subfunctions/__init__.py <==
#==============================================================================#
#  Author:       Dominik Müller                                                #
#  Copyright:    2020 IT-Infrastructure for Translational Medical Research,    #
#                University of Augsburg                                        #
#                                                                              #
#  This program is free software: you can redistribute it and/or modify        #
#  it under the terms of the GNU General Public License as published by        #
#  the Free Software Foundation, either version 3 of the License, or           #
#  (at your option) any later version.                                         #
#                                                                              #
#  This program is distributed in the hope that it will be useful,             #
#  but WITHOUT ANY WARRANTY; without even the implied warranty of              #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
#  GNU General Public License for more details.                                #
#                                                                              #
#  You should have received a copy of the GNU General Public License           #
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#==============================================================================#
from miscnn.processing.subfunctions.clipping import Clipping
from miscnn.processing.subfunctions.normalization import Normalization
from miscnn.processing.subfunctions.resampling import Resampling
from miscnn.processing.subfunctions.resize import Resize

==> miscnn-1.2.1.tar.gz: miscnn-1.2.1/miscnn/processing/subfunctions/__init__.py <==
#==============================================================================#
#  Author:       Dominik Müller                                                #
#  Copyright:    2020 IT-Infrastructure for Translational Medical Research,    #
#                University of Augsburg                                        #
#                                                                              #
#  This program is free software: you can redistribute it and/or modify        #
#  it under the terms of the GNU General Public License as published by        #
#  the Free Software Foundation, either version 3 of the License, or           #
#  (at your option) any later version.                                         #
#                                                                              #
#  This program is distributed in the hope that it will be useful,             #
#  but WITHOUT ANY WARRANTY; without even the implied warranty of              #
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
#  GNU General Public License for more details.                                #
#                                                                              #
#  You should have received a copy of the GNU General Public License           #
#  along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#==============================================================================#
from miscnn.processing.subfunctions.clipping import Clipping
from miscnn.processing.subfunctions.normalization import Normalization
from miscnn.processing.subfunctions.resampling import Resampling
from miscnn.processing.subfunctions.resize import Resize
from miscnn.processing.subfunctions.padding import Padding
from miscnn.processing.subfunctions.transform_HU import TransformHU
